/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 2001
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.servlet;

import ccl.util.DBUtil;
import ccl.util.Util;
import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.math.BigDecimal;
import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Enumeration;
import java.util.Vector;
import org.xml.sax.Attributes;
/*import org.xml.sax.HandlerBase;*/
import org.xml.sax.InputSource;
/*//import org.xml.sax.Parser;*/
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;
/**
 * Sax2 parser for xml database input.
 *
 * @author    Chr. Clemens Lee (clemens@kclee.com)
 * @version   $Id: XMLImportHandler.java,v 1.5 2002/05/20 12:09:16 clemens Exp clemens $
 */
public class XMLImportHandler extends DefaultHandler 
{
    /**
     * XML Parser used. Part of sun's xml-tr2 package.
     */
    static private final String S_PARSER = "org.apache.xerces.parsers.SAXParser";

    /**
     * Tag name of column.
     */
    static final String S_TAG_COLUMN = "column";

    /**
     * Tag name of columns.
     */
    static final String S_TAG_COLUMNS = "columns";

    /**
     * Tag name of database.
     */
    static final String S_TAG_DATABASE = "database";

    /**
     * Tag name of row.
     */
    static final String S_TAG_ROW = "row";

    /**
     * Tag name of rows.
     */
    static final String S_TAG_ROWS = "rows";

    /**
     * Tag name of table.
     */
    static final String S_TAG_TABLE = "table";

    /**
     * Tag name of value.
     */
    static final String S_TAG_VALUE = "value";

    /**
     * StringBuffer used to store the element's CDATA/content in it.
     */
    private StringBuffer _sbCDATA = new StringBuffer();

    private Connection _connection = null;

    /**
     * Creates an instance of this sax handler.
     */
    public XMLImportHandler( Connection connection ) 
{
        super();

        _connection = connection;
    }

    /**
     * Gets the CDATA from the elements.
     *
     * @param   ac_       an array of chars, representing the CDATA.
     * @param   start_    the start index from ac.
     * @param   length_   the length to copy from ac from start index.
     */
    public void characters( char ac_[], int start_, int length_ ) 
{
        _sbCDATA.append( ac_, start_, length_ );
    }

    private String _sTableName = null;

    /**
     * Gets invoked from the sax xml parser whenever a new element starts.
     */
    public void startElement( String       namespaceURI_
                              , String     localName_
                              , String     qName_
                              , Attributes atts_         )
    {
        if ( qName_.equals( S_TAG_TABLE ) ) 
        {
            _sTableName = atts_.getValue( "name" );
            
            try 
            {
                DBUtil.deleteTable( _connection, _sTableName );
            }
 catch( SQLException sqlException ) 
{
                Util.printlnErr( sqlException );
            }
        }
        if ( qName_.equals( S_TAG_COLUMNS ) ) 
{
            _vColumns = new Vector();
        }
        if ( qName_.equals( S_TAG_ROW ) ) 
{
            _vValues = new Vector();
        }
        _sbCDATA.setLength( 0 );
    }

    private Vector _vColumns = null;
    private Vector _vValues = null;
    private PreparedStatement _statement = null;
    private Vector _vTypes = null;

    /**
     * Gets invoked from the sax xml parser whenever an element 
     * closes.
     */
    public void endElement( String       namespaceURI_
                            , String     localName_
                            , String     qName_        )
    {
        if ( localName_.equals( S_TAG_COLUMN ) )
        {
            _vColumns.addElement( _sbCDATA.toString() );
        }
        else if ( localName_.equals( S_TAG_COLUMNS ) ) 
        {
            String sInsert = "insert into " 
                   + _sTableName
                   + " (";
            String sQuestionMarks = "";
            Enumeration eColumns = _vColumns.elements();
            while( eColumns.hasMoreElements() ) 
{
                sInsert += (String)eColumns.nextElement();
                sQuestionMarks += "?";
                if ( eColumns.hasMoreElements() ) 
{
                    sInsert += ",";
                    sQuestionMarks += ",";
                }
            }
            sInsert +=") values ("
                   + sQuestionMarks
                   + ")";
            Util.debug( this, "endElement(..).Empty insert call: " + sInsert );
            
            try
            {
                _statement = _connection.prepareStatement( sInsert );
                Util.debug( this, "endElement(..)._statement: " + _statement );

                // find out types
                DatabaseMetaData meta = _connection.getMetaData();
                Util.debug( this, "endElement(..).table: " + _sTableName );
                ResultSet result = meta.getColumns( null, null, _sTableName.toLowerCase(), null );
                _vTypes = new Vector();
                int column = 0;
                Util.debug( this, "endElement(..).GET_TYPES" );
                while( result.next() )
                {
                    String sXMLColumn = (String)_vColumns.elementAt( column );
                    String sName = result.getString( 4 ); // COLUMN_NAME
                    Util.debug( this, "endElement(..).sName: " + sName );
                    if ( !sXMLColumn.equals( sName ) )
                    {
                        Util.printlnErr( "Xml column '"
                                         + sXMLColumn
                                         + "' in table '"
                                         + _sTableName
                                         + "' does not match real column '"
                                         + sName
                                         + "' in the database!" );
                    }
                    _vTypes.addElement( result.getString( 6 ) ); // TYPE_NAME
                    column++;
                }
                result.close();
            }
            catch( SQLException sqlException ) 
            {
                Util.printlnErr( sqlException );
            }

        }
 else if ( localName_.equals( S_TAG_DATABASE ) ) 
{
        } 
else if ( localName_.equals( S_TAG_ROW ) ) 
{

            try 
            {
                if ( _statement == null )
                {
                    Util.debug( this, "endElement(..)._statement is indeed null!" );
                }
                Enumeration eValues = _vValues.elements();
                Enumeration eTypes  = _vTypes .elements();
                int index = 1;
                while( eValues.hasMoreElements() ) 
                {
                    String sType  = (String)eTypes .nextElement();
                    String sValue = (String)eValues.nextElement();
                    Util.debug( this, "endElement(..).type: --->" + sType + "<---" );
                    if ( sType.equals( "int" ) )
                    {
                        _statement.setInt( index, Util.atoi( sValue ) );
                    } 
                    else if ( sType.equals( "double precis" ) )
                    {
                        _statement.setDouble( index, Util.atod( sValue ) );
                    }
                    else if ( sType.equals( "numeric" ) )
                    {
                        _statement.setBigDecimal( index, BigDecimal.valueOf( Util.atol( sValue ) ) );
                    }
                    else 
                    {
                        _statement.setString( index, sValue );
                    }
                    index++;
                }
                _statement.executeUpdate();
            }
            catch( SQLException sqlException ) 
            {
                Util.printlnErr( sqlException );
            }
            catch( Exception exception ) 
            {
                Util.printlnErr( exception );
            }

        }
 else if ( localName_.equals( S_TAG_ROWS ) ) 
{
            /*
            try 
            {
                _statement.close();
            }
            catch( SQLException sqlException ) 
            {
                Util.printlnErr( sqlException );
            }
            */
        }
 else if ( localName_.equals( S_TAG_TABLE ) ) 
{
        }
 else if ( localName_.equals( S_TAG_VALUE ) ) 
{
            _vValues.addElement( _sbCDATA.toString() );
        }
    }

    /**
     * This method creates an instance of this parser and pipes the specified
     * file through it.
     *
     * @exception   Exception    if anything goes wrong while parsing.
     */
    static public void parse( Connection connection_, String sFileName_ )
        throws Exception
    {
        System.getProperties().put( "org.xml.sax.driver", S_PARSER );
        XMLImportHandler xmlimporthandler = new XMLImportHandler( connection_ );
        XMLReader reader = XMLReaderFactory.createXMLReader();
        //XMLReader parser = (XMLReader)Class.forName( S_PARSER ).newInstance();
        reader.setContentHandler( xmlimporthandler );
        reader.setErrorHandler  ( xmlimporthandler );

        InputSource pInputSource = new InputSource( new BufferedReader( new FileReader( sFileName_ ) ) );

        reader.parse( pInputSource );        
    }

    /*static public void main( String[] args ) {
        try {
            parse( args[0] );
        } catch( Exception e ) {
            System.err.println( e.toString() );
        }
        System.exit(0);
        }*/
}
