/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 2001
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.servlet;

import ccl.util.FileUtil;
import ccl.util.Util;
//import com.oreilly.servlet.MultipartRequest;
import http.utils.multipartrequest.MultipartRequest;
import http.utils.multipartrequest.ServletMultipartRequest;
import java.io.File;
import java.io.IOException;
import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Enumeration;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * This servlet reads in an xml file that has been created
 * with an XMLExporter class. 
 * To make use of this class
 * inherit from this one and implement the 'getConnection'
 * and 'getTitle()' methods.
 *
 * @author    Chr. Clemens Lee (clemens@kclee.com)
 * @version   $Id: XMLImporter.java,v 1.3 2002/05/20 12:09:15 clemens Exp clemens $
 */
abstract public class XMLImporter extends HttpServlet 
{
    public void doGet(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException
    {
        HTML html = new HTML( response );
        html.printTitle( getTitle() );

        html.println( "<form method=\"post\" enctype=\"multipart/form-data\" action=\""
                      + Util.getObjectName( this ) 
                      + "\">" );
        html.println( "Specify name of xml file to import:" );
        html.println( "<input type=\"file\" name=\"xmlfile\"><p>" );
        html.println( "<input type=\"submit\" name=\"Submit\">" );
        html.println( "</form>" );
        
        html.close();
    }

    public void doPost(HttpServletRequest request, HttpServletResponse response)
        throws IOException, ServletException
    {
        HTML html = new HTML( response );
        html.printTitle( getTitle() );

        /*
        MultipartRequest multirequest = new MultipartRequest( request
                                                              , "."
                                                              , 15*1024*1024 );
        File file = multirequest.getFile( "xmlfile" );
        */
        String sXMLFile = FileUtil.concatPath( FileUtil.getTempDir()
                                               , "xmlfile" );
        MultipartRequest multirequest = new ServletMultipartRequest
               ( request
                 , sXMLFile );
        Util.debug( this, "doPost(..).file: " + sXMLFile );

        try
        {
            Connection connection = getConnection();
            //connection.setAutoCommit( false );
            XMLImportHandler.parse( connection
                                    , sXMLFile );
            //connection.commit();
            connection.close();
        }
        catch( Exception exception ) 
        {
            Util.printlnErr( exception );
        }

        html.println( "XML file was received successfully." );

        html.close();
    }

    /**
     * Creates a connection object in the class which uses
     * this class.
     */
    abstract public Connection getConnection();

    /**
     * Returns the title used for the html page.
     */
    abstract public String     getTitle     ();
}
