/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 1999
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.servlet.test;

import ccl.servlet.XMLImportHandler;
import ccl.util.ClassPathUtil;
import ccl.util.DBUtil;
import ccl.util.FileUtil;
import ccl.util.Test;
import ccl.util.Util;
import java.io.File;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * This class conducts some basic tests of the 
 * ccl.servlet.XMLImportHandler
 * class using a postgresql database, if it exists. In that
 * case it creates a database with name ccltest. Be sure you
 * don't have a database with the same name in use, as that
 * would be dropped with all its data. If you have no postgresql
 * in your system, the tests will be skipped.
 *
 * @version $Id: XMLImportHandlerTest.java,v 1.2 2002/05/20 12:09:16 clemens Exp clemens $
 * @author  Chr. Clemens Lee
 */
public class XMLImportHandlerTest extends Test 
{
    public XMLImportHandlerTest() 
{
        super();
    }

    public XMLImportHandlerTest( Test pTest_ ) 
{
        super( pTest_ );
    }

    /**
     * Insert your test code into the _doIt() method and
     * test bugs with 'bugIf( boolean expression );' or
     * 'bugIf( boolean expression, "comment about what went wrong" );'.
     * Then just invoke the main routine.
     *
     * @exception   Exception   if anything goes wrong the test fails as well.
     */
    protected void _doIt()
        throws Exception
    {
        Connection connection = null;
        try
        {
            connection = DBUtil.createPGConnection( "template1" );
        }
        catch( Exception exception )
        {
            // ok, no postgresql existing, just skip tests
            Util.print( " No PostgreSQL database found, skipping tests! " );

            return;
        }
        Statement statement = connection.createStatement();

        try
        {
            statement.executeUpdate( "drop database ccltest" );
        }
        catch( SQLException sqlException )
        {
            // if test database does not exist yet, fine
            Util.printlnErr( String.valueOf( sqlException ) );
        }
        statement.executeUpdate( "create database ccltest" );
        statement.close();
        connection.close();

        connection = DBUtil.createPGConnection( "ccltest" );
        statement = connection.createStatement();

        // so far, so good
        assert( true );

        // get test directory and add create_tables.sql
        String sCreateTablesFile = FileUtil.concatPath( ClassPathUtil.getApplicationHome( this )
                                               , "test" )
               + File.separator + "create_tables.sql";
        String sCreateTablesSQL = FileUtil.readFile( sCreateTablesFile );
        statement.executeUpdate( sCreateTablesSQL );

        // again - so far, so good
        assert( true );

        ResultSet result = statement.executeQuery( "select count(*) from tblTransaction" );
        result.next();
        assert( Util.atoi( result.getString( 1 ) ) == 0 );
        result.close();
        
        statement.close();

        //
        // database is set up, now import xml file
        //

        String sImportFile = FileUtil.concatPath( ClassPathUtil.getApplicationHome( this )
                                                  , "test" )
               + File.separator + "xmlimport_test.xml";
        XMLImportHandler.parse( connection, sImportFile );

        statement = connection.createStatement();
        result = statement.executeQuery( "select count(*) from tblTransaction" );
        result.next();
        assert( Util.atoi( result.getString( 1 ) ) == 3 );
        result.close();
        statement.close();

        connection.close();

        //
        // do it again and old stuff should be removed first
        //

        connection = DBUtil.createPGConnection( "ccltest" );
        statement = connection.createStatement();
        sImportFile = FileUtil.concatPath( ClassPathUtil.getApplicationHome( this )
                                                  , "test" )
               + File.separator + "xmlimport_test2.xml";
        XMLImportHandler.parse( connection, sImportFile );

        statement = connection.createStatement();
        result = statement.executeQuery( "select count(*) from tblTransaction" );
        result.next();
        assert( Util.atoi( result.getString( 1 ) ) == 4 );
        result.close();
        statement.close();
    }

    public static void main( String[] asArg_ ) 
{
        Test pTest = (Test)(new XMLImportHandlerTest());
        pTest.setVerbose( true );
        pTest.run();
        pTest.printResult( pTest );

        System.exit( 0 );
    }
}
