/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 1999
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.swing;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Insets;
import javax.swing.border.AbstractBorder;

/**
 * A border used in most ccl widgets, which is similar to the 
 * border used in MS Windows.
 *
 * @version  $Id: CCLBorder.java,v 1.9 2002/05/12 07:36:21 clemens Exp clemens $
 * @author   <a href="http://www.kclee.com/clemens/">
 *           Chr. Clemens Lee</a>
 *           &lt;<a href="mailto:clemens@kclee.com">
 *           clemens@kclee.com
 *           </a>>
 */
public class CCLBorder extends AbstractBorder 
{
    public CCLBorder() 
    {
        super();
    }

    public void paintBorder(Component c,
                            Graphics g,
                            int x,
                            int y,
                            int width,
                            int height)
    {
        int w = width  - 1;
        int h = height - 1;
        Color clrBackground = c.getBackground();
        if ( c.getParent() != null ) 
        {
            clrBackground = c.getParent().getBackground();
        }
        
        // 1. Rahmen
        // Originalfarbe
        g.setColor(clrBackground);
        g.drawLine(x, y, x + w, y);
        g.drawLine(x, y, x, y + h);
        g.drawLine(x + w, y, x + w, y + h);
        g.drawLine(x, y + h, x + w, y + h);
        
        // 2. Rahmen
        // links darker
        g.setColor(clrBackground.darker());
        g.drawLine(x + 1, y + 1, x + w - 1, y + 1);
        g.drawLine(x + 1, y + 1, x + 1    , y + h - 1);
        // unten heller
        g.setColor(clrBackground.brighter());
        g.drawLine(x + w - 1, y + h - 1, x + w - 1, y + 1);
        g.drawLine(x + w - 1, y + h - 1, x + 1    , y + h - 1);
        
        // 3. Rahmen
        // oben links
        g.setColor(clrBackground.darker().darker());
        g.drawLine(x + 2, y + 2, x + w - 2, y + 2);
        g.drawLine(x + 2, y + 2, x + 2    , y + h - 2);
        // unten rechts
        g.setColor(clrBackground);
        g.drawLine(x + w - 2, y + h - 2, x + w - 2, y + 2);
        g.drawLine(x + w - 2, y + h - 2, x + 2    , y + h - 2);
    }

    public Insets getBorderInsets(Component c) 
    {
        return new Insets(3, 3, 3, 3);
    }
    
    public boolean isBorderOpaque() 
    {
        return true;
    }
}

