/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 1999
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.swing;

import ccl.swing.AutoGridBagLayout;
import ccl.swing.SwingUtil;
import ccl.util.Util;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.DefaultFocusManager;
import javax.swing.FocusManager;
import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;


/**
 * Dialog with memory information.
 *
 * @version  $Id: MemoryDialog.java,v 1.7 2002/05/20 12:09:31 clemens Exp clemens $
 * @author   <a href="http://www.kclee.com/clemens/">
 *           Chr. Clemens Lee</a>
 *           &lt;<a href="mailto:clemens@kclee.com">
 *           clemens@kclee.com
 *           </a>>
 */
public class MemoryDialog extends ExitJFrame
                          implements ActionListener
{
    private MemoryPanel _pMemoryPanel = null;
    private JButton _btnOK = null;

    public MemoryDialog() 
    {
        this(new Frame());
    }
    
    public MemoryDialog( Frame frmParent_ ) 
    {
        super( "Memory" );
        
        setBackground( frmParent_.getBackground() );

        AutoGridBagLayout pAutoGridBagLayout = new AutoGridBagLayout();

        getContentPane().setLayout( pAutoGridBagLayout );
        ((JPanel)getContentPane()).setBorder( BorderFactory.
                                              createEmptyBorder( 5, 5, 5, 5 ) );

        _pMemoryPanel = new MemoryPanel();
        getContentPane().add( _pMemoryPanel );
        pAutoGridBagLayout.endLine();

        getContentPane().add( Box.createVerticalStrut( 2 ) );
        pAutoGridBagLayout.endLine();

        _btnOK = new JButton( "OK" );
        _btnOK.addActionListener( this );

        getContentPane().add( _btnOK );
        
        //FocusManager.setCurrentManager( new DefaultFocusManager() );

        //SwingUtil.setInitialFocus( this, _btnOK );
        addWindowListener( new WindowAdapter() {
                public void windowOpened( WindowEvent pWindowEvent_ ) 
                {
                    //SwingUtilities.invokeLater( new Runnable() {
                    //public void run() {
                    _btnOK.requestFocus();
                    //  }
                    //} );
                }
            } );

        pack();

        SwingUtil.centerComponent( this) ;
        show();

        _pMemoryPanel.start();
    }

    public void setVisible( boolean bVisible_ ) 
    {
        if ( bVisible_ ) 
        {
            //
        }
        else 
        {
            _pMemoryPanel.stop();
        }

        super.setVisible( bVisible_ );
    }

    public void actionPerformed(ActionEvent pActionEvent_) 
    {
        Object oSource = pActionEvent_.getSource();
        if (oSource == _btnOK) 
        {
            exit();
        }
    }
}
