/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 1999
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */
package ccl.swing;

import ccl.util.Util;
import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Icon;
import javax.swing.KeyStroke;

/**
 * Implements action and Runnable.
 * 
 * @author  Chr. Clemens Lee
 * @version $Id: RunnableAction.java,v 1.5 2002/05/20 12:09:35 clemens Exp clemens $
 */
public abstract class RunnableAction extends AbstractAction
                                     implements Runnable
{
    //public final static String S_MAIN_FRAME = "MainFrame";

    private MainJFrame _pMainFrame = null;

    public RunnableAction() 
{
        super();
    }

    public RunnableAction(String param1_) 
{
        super(param1_);
    }

    public RunnableAction(String param1_, Icon param2_) 
{
        super(param1_, param2_);
    }

    public void setMainFrame( MainJFrame pMainFrame_ ) 
{
        _pMainFrame = pMainFrame_;
    }

    public Object getValue( String sKey_ ) 
{
        Object oRetVal = super.getValue( sKey_ );
        if ( sKey_.equals( NAME ) ) 
{
            String sRetVal = (String)oRetVal;
            sRetVal = Util.replace( sRetVal, "&", "" );
            oRetVal = sRetVal;                   
        }

        return oRetVal;
    }

    public Character getMnemonic() 
{
        Character charRetVal = null;

        String sName = (String)super.getValue( NAME );

        int indexMnemonic = sName.indexOf( '&' );
        if ( indexMnemonic != -1 && 
             indexMnemonic < sName.length() ) 
        {
            charRetVal = new Character( sName.charAt
                                        ( indexMnemonic + 1 ) );
        }

        return charRetVal;
    }

    /*
     * --- overwritten methods of class 'javax.swing.AbstractAction' ---
     */

    public final void actionPerformed( ActionEvent pActionEvent_ ) 
{
        Util.panicIf( _pMainFrame == null );
        _pMainFrame.runAction( this );
    }
    
    public abstract void run();

    public KeyStroke getAccelerator() 
{
        return null;
    }
}
