/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is taken from a news group and added to 
 * the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Marcel Nijman.
 * Portions created by Marcel Nijman are Copyright (C) 1999
 * Marcel Nijman. All Rights Reserved.
 *
 * Contributor(s): Marcel Nijman <marcel@mbfys.kun.nl>
 *                 Maintained by Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.swing;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.event.ComponentListener;

import javax.swing.JSplitPane;

/**
 * This class provides a workaround for a bug in the 
 * JSplitPane.setDividerLocation( double ) method.
 *
 * @author  Marcel Nijman, Chr. Clemens Lee
 * @version $Id: SplitPane.java,v 1.2 2002/05/20 12:09:36 clemens Exp clemens $
 */
public class SplitPane extends JSplitPane 
{
    private boolean _bPainted = false;
    private boolean _bProportionalLocation = false;
    private double  _dProportionalLocation = 0.5d;

    public SplitPane() 
    {
        super();
    }

    public SplitPane(int param1_) 
    {
        super(param1_);
    }

    public SplitPane(int param1_, Component param2_, Component param3_) 
    {
        super(param1_, param2_, param3_);
    }
    
    public SplitPane(int param1_, boolean param2_) 
    {
        super(param1_, param2_);
    }
    
    public SplitPane(int param1_, boolean param2_, Component param3_, Component param4_) 
    {
        super(param1_, param2_, param3_, param4_);
    }

    public void setDividerLocation( double dLocation_ ) 
    {
        if ( !_bPainted ) 
        {
            _bProportionalLocation = true;
            _dProportionalLocation = dLocation_;
        }
        else 
        {
            super.setDividerLocation( dLocation_ );
        }
    }

    public void setDividerLocation( int location_ ) 
    {
        _bProportionalLocation = false;

        super.setDividerLocation( location_ );
    }

    public void paint( Graphics graphics_ ) 
    {
        if ( !_bPainted ) 
        {
            _bPainted = true;
            setDividerLocation( _dProportionalLocation );
        }

        super.paint( graphics_ );
    }
}
