/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl java library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 2001
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.swing.test;

import ccl.swing.SwingUtil;
import ccl.util.FileUtil;
import ccl.util.Test;
import ccl.util.Util;
import java.awt.Frame;
import java.awt.Window;
import java.util.Vector;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JPanel;
import javax.swing.JTextField;

/**
 * Tests for ccl.swing.SwingUtil utility methods.
 *
 * @version $Id: SwingUtilTest.java,v 1.3 2002/05/20 12:09:40 clemens Exp clemens $
 * @author  Chr. Clemens Lee (clemens@kclee.com)
 */
public class SwingUtilTest extends Test 
{
    public SwingUtilTest() 
{
        super();
    }

    public SwingUtilTest( Test pTest_ ) 
{
        super( pTest_ );
    }

    /**
     * Tests for ccl.swing.SwingUtil utility methods.
     *
     * @exception   Exception   for whatever can go wrong.
     */
    protected void _doIt()
        throws Exception
    {
        Test pTest = null;

        pTest = (Test)(new DoubleListTest( this ));
        pTest.run();
        setTests( pTest );
        
        pTest = (Test)(new DateFieldTest( this ));
        pTest.run();
        setTests( pTest );

        final Frame frame = new Frame();

        // test for getFirstComponent(..) with a file chooser.
        final JFileChooser pFileChooser = new JFileChooser
            ( FileUtil.getTempDir() );
        pFileChooser.setDialogTitle( "SwingUtilTest" );

        pFileChooser.setFileSelectionMode( JFileChooser.FILES_AND_DIRECTORIES );

        Runnable runFileChooser = new Runnable() {
            public void run() 
{
                pFileChooser.showDialog( frame, null );
            }
        };

        Thread thrFileChooser = new Thread( runFileChooser );
        thrFileChooser.start();
        Util.sleep( 8 );

        assert( frame.getOwnedWindows().length == 1 );
        assert( frame.getOwnedWindows()[ 0 ] instanceof JDialog );
        JDialog dialog = (JDialog)frame.getOwnedWindows()[ 0 ];
        JPanel panel = (JPanel)SwingUtil.getFirstComponent( dialog
                                                            , "javax.swing.JPanel" );
        bugIf( panel == null );

        //Util.setDebug( true );
        JTextField textField = (JTextField)SwingUtil.getFirstComponent( dialog
                                                                       , "javax.swing.plaf.metal.MetalFileChooserUI$1" );
        bugIf( textField == null );

        bugIf( dialog == null );

        dialog.setVisible( false );
    }

    public static void main( String[] asArg_ ) 
{
        Test pTest = (Test)(new SwingUtilTest());
        pTest.setVerbose( true );
        pTest.run();
        pTest.printResult( pTest );

        System.exit( 0 );
    }
}
