/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is the reusable ccl library
 * (http://www.kclee.com/clemens/java/ccl/).
 *
 * The Initial Developer of the Original Code is Chr. Clemens Lee.
 * Portions created by Chr. Clemens Lee are Copyright (C) 1999
 * Chr. Clemens Lee. All Rights Reserved.
 *
 * Contributor(s): Chr. Clemens Lee <clemens@kclee.com>
 */

package ccl.util;

/**
 * Singleton: Ensure a class only has one
 * instance, and provide a global point of access to
 * it.
 * 
 * @version $Id: Singleton.java,v 1.3 2002/05/20 12:09:48 clemens Exp clemens $
 * @author <a href="http://www.kclee.com/clemens/">
 *         Chr. Clemens Lee</a>
 *         &lt;<a href="mailto:clemens@kclee.com">
 *         clemens@kclee.com
 *         </a>>
 */
public class Singleton 
{
    /**
     * For each Class type an instance gets saved so we can
     * inherit and use Singleton for different other classes.
     */
    private static Object _oInstance = null;
    
    /**
     * Users can't instantiate an object themself. They need to
     * use getInstance instead.
     */
    protected Singleton() 
{
        super();
    }
    
    public static Object getInstance() 
{
        if (_oInstance == null) 
{
            _oInstance = new Object();
        }
        
        return _oInstance;
    }
}
